"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Compute(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AVAILABILITY_SETS_FIELD_NUMBER: builtins.int
    CAPACITY_RESERVATION_GROUPS_FIELD_NUMBER: builtins.int
    HOST_GROUPS_FIELD_NUMBER: builtins.int
    IMAGES_FIELD_NUMBER: builtins.int
    PROXIMITY_PLACEMENT_GROUPS_FIELD_NUMBER: builtins.int
    RESTORE_POINT_COLLECTIONS_FIELD_NUMBER: builtins.int
    SSH_PUBLIC_KEYS_FIELD_NUMBER: builtins.int
    @property
    def availability_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AvailabilitySets]: ...
    @property
    def capacity_reservation_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CapacityReservationGroups]: ...
    @property
    def host_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostGroups]: ...
    @property
    def images(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Images]: ...
    @property
    def proximity_placement_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProximityPlacementGroups]: ...
    @property
    def restore_point_collections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RestorePointCollections]: ...
    @property
    def ssh_public_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SshPublicKeys]: ...
    def __init__(
        self,
        *,
        availability_sets: collections.abc.Iterable[global___AvailabilitySets] | None = ...,
        capacity_reservation_groups: collections.abc.Iterable[global___CapacityReservationGroups] | None = ...,
        host_groups: collections.abc.Iterable[global___HostGroups] | None = ...,
        images: collections.abc.Iterable[global___Images] | None = ...,
        proximity_placement_groups: collections.abc.Iterable[global___ProximityPlacementGroups] | None = ...,
        restore_point_collections: collections.abc.Iterable[global___RestorePointCollections] | None = ...,
        ssh_public_keys: collections.abc.Iterable[global___SshPublicKeys] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["availability_sets", b"availability_sets", "capacity_reservation_groups", b"capacity_reservation_groups", "host_groups", b"host_groups", "images", b"images", "proximity_placement_groups", b"proximity_placement_groups", "restore_point_collections", b"restore_point_collections", "ssh_public_keys", b"ssh_public_keys"]) -> None: ...

global___Microsoft_Compute = Microsoft_Compute

@typing_extensions.final
class SshPublicKeys(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PUBLIC_KEY_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    public_key: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        public_key: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "name", b"name", "public_key", b"public_key", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___SshPublicKeys = SshPublicKeys

@typing_extensions.final
class RestorePointCollectionsRestorePoints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    EXCLUDE_DISKS_FIELD_NUMBER: builtins.int
    SOURCE_RESTORE_POINT_FIELD_NUMBER: builtins.int
    TIME_CREATED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def exclude_disks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApiEntityReference]: ...
    @property
    def source_restore_point(self) -> global___ApiEntityReference: ...
    time_created: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        exclude_disks: collections.abc.Iterable[global___ApiEntityReference] | None = ...,
        source_restore_point: global___ApiEntityReference | None = ...,
        time_created: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "source_restore_point", b"source_restore_point"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["exclude_disks", b"exclude_disks", "name", b"name", "resource_info", b"resource_info", "source_restore_point", b"source_restore_point", "time_created", b"time_created"]) -> None: ...

global___RestorePointCollectionsRestorePoints = RestorePointCollectionsRestorePoints

@typing_extensions.final
class ApiEntityReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___ApiEntityReference = ApiEntityReference

@typing_extensions.final
class RestorePointCollections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    RESTORE_POINT_COLLECTIONS_RESTORE_POINTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    @property
    def source(self) -> global___RestorePointCollectionSourceProperties: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def restore_point_collections_restore_points(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RestorePointCollectionsRestorePoints]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        source: global___RestorePointCollectionSourceProperties | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        restore_point_collections_restore_points: collections.abc.Iterable[global___RestorePointCollectionsRestorePoints] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "name", b"name", "resource_info", b"resource_info", "restore_point_collections_restore_points", b"restore_point_collections_restore_points", "source", b"source", "tags", b"tags"]) -> None: ...

global___RestorePointCollections = RestorePointCollections

@typing_extensions.final
class RestorePointCollectionSourceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___RestorePointCollectionSourceProperties = RestorePointCollectionSourceProperties

@typing_extensions.final
class ProximityPlacementGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    COLOCATION_STATUS_FIELD_NUMBER: builtins.int
    PROXIMITY_PLACEMENT_GROUP_TYPE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    @property
    def colocation_status(self) -> global___InstanceViewStatus: ...
    proximity_placement_group_type: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        colocation_status: global___InstanceViewStatus | None = ...,
        proximity_placement_group_type: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["colocation_status", b"colocation_status", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["colocation_status", b"colocation_status", "location", b"location", "name", b"name", "proximity_placement_group_type", b"proximity_placement_group_type", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___ProximityPlacementGroups = ProximityPlacementGroups

@typing_extensions.final
class InstanceViewStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    DISPLAY_STATUS_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    code: builtins.str
    display_status: builtins.str
    level: builtins.str
    message: builtins.str
    time: builtins.str
    def __init__(
        self,
        *,
        code: builtins.str = ...,
        display_status: builtins.str = ...,
        level: builtins.str = ...,
        message: builtins.str = ...,
        time: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "display_status", b"display_status", "level", b"level", "message", b"message", "time", b"time"]) -> None: ...

global___InstanceViewStatus = InstanceViewStatus

@typing_extensions.final
class Images(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EXTENDED_LOCATION_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    HYPER_V_GENERATION_FIELD_NUMBER: builtins.int
    SOURCE_VIRTUAL_MACHINE_FIELD_NUMBER: builtins.int
    STORAGE_PROFILE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def extended_location(self) -> global___ExtendedLocation: ...
    location: builtins.str
    name: builtins.str
    hyper_v_generation: builtins.str
    source_virtual_machine: builtins.str
    @property
    def storage_profile(self) -> global___ImageStorageProfile: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        extended_location: global___ExtendedLocation | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        hyper_v_generation: builtins.str = ...,
        source_virtual_machine: builtins.str = ...,
        storage_profile: global___ImageStorageProfile | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["extended_location", b"extended_location", "resource_info", b"resource_info", "storage_profile", b"storage_profile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["extended_location", b"extended_location", "hyper_v_generation", b"hyper_v_generation", "location", b"location", "name", b"name", "resource_info", b"resource_info", "source_virtual_machine", b"source_virtual_machine", "storage_profile", b"storage_profile", "tags", b"tags"]) -> None: ...

global___Images = Images

@typing_extensions.final
class ImageStorageProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_DISKS_FIELD_NUMBER: builtins.int
    OS_DISK_FIELD_NUMBER: builtins.int
    ZONE_RESILIENT_FIELD_NUMBER: builtins.int
    @property
    def data_disks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ImageDataDisk]: ...
    @property
    def os_disk(self) -> global___ImageOSDisk: ...
    zone_resilient: builtins.bool
    def __init__(
        self,
        *,
        data_disks: collections.abc.Iterable[global___ImageDataDisk] | None = ...,
        os_disk: global___ImageOSDisk | None = ...,
        zone_resilient: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["os_disk", b"os_disk"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_disks", b"data_disks", "os_disk", b"os_disk", "zone_resilient", b"zone_resilient"]) -> None: ...

global___ImageStorageProfile = ImageStorageProfile

@typing_extensions.final
class ImageOSDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BLOB_URI_FIELD_NUMBER: builtins.int
    CACHING_FIELD_NUMBER: builtins.int
    DISK_ENCRYPTION_SET_FIELD_NUMBER: builtins.int
    DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    MANAGED_DISK_FIELD_NUMBER: builtins.int
    OS_STATE_FIELD_NUMBER: builtins.int
    OS_TYPE_FIELD_NUMBER: builtins.int
    SNAPSHOT_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_TYPE_FIELD_NUMBER: builtins.int
    blob_uri: builtins.str
    caching: builtins.str
    @property
    def disk_encryption_set(self) -> global___DiskEncryptionSetParameters: ...
    disk_size_gb: builtins.int
    managed_disk: builtins.str
    os_state: builtins.str
    os_type: builtins.str
    snapshot: builtins.str
    storage_account_type: builtins.str
    def __init__(
        self,
        *,
        blob_uri: builtins.str = ...,
        caching: builtins.str = ...,
        disk_encryption_set: global___DiskEncryptionSetParameters | None = ...,
        disk_size_gb: builtins.int = ...,
        managed_disk: builtins.str = ...,
        os_state: builtins.str = ...,
        os_type: builtins.str = ...,
        snapshot: builtins.str = ...,
        storage_account_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["disk_encryption_set", b"disk_encryption_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["blob_uri", b"blob_uri", "caching", b"caching", "disk_encryption_set", b"disk_encryption_set", "disk_size_gb", b"disk_size_gb", "managed_disk", b"managed_disk", "os_state", b"os_state", "os_type", b"os_type", "snapshot", b"snapshot", "storage_account_type", b"storage_account_type"]) -> None: ...

global___ImageOSDisk = ImageOSDisk

@typing_extensions.final
class ImageDataDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BLOB_URI_FIELD_NUMBER: builtins.int
    CACHING_FIELD_NUMBER: builtins.int
    DISK_ENCRYPTION_SET_FIELD_NUMBER: builtins.int
    DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    LUN_FIELD_NUMBER: builtins.int
    MANAGED_DISK_FIELD_NUMBER: builtins.int
    SNAPSHOT_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_TYPE_FIELD_NUMBER: builtins.int
    blob_uri: builtins.str
    caching: builtins.str
    @property
    def disk_encryption_set(self) -> global___DiskEncryptionSetParameters: ...
    disk_size_gb: builtins.int
    lun: builtins.int
    managed_disk: builtins.str
    snapshot: builtins.str
    storage_account_type: builtins.str
    def __init__(
        self,
        *,
        blob_uri: builtins.str = ...,
        caching: builtins.str = ...,
        disk_encryption_set: global___DiskEncryptionSetParameters | None = ...,
        disk_size_gb: builtins.int = ...,
        lun: builtins.int = ...,
        managed_disk: builtins.str = ...,
        snapshot: builtins.str = ...,
        storage_account_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["disk_encryption_set", b"disk_encryption_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["blob_uri", b"blob_uri", "caching", b"caching", "disk_encryption_set", b"disk_encryption_set", "disk_size_gb", b"disk_size_gb", "lun", b"lun", "managed_disk", b"managed_disk", "snapshot", b"snapshot", "storage_account_type", b"storage_account_type"]) -> None: ...

global___ImageDataDisk = ImageDataDisk

@typing_extensions.final
class DiskEncryptionSetParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___DiskEncryptionSetParameters = DiskEncryptionSetParameters

@typing_extensions.final
class ExtendedLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type"]) -> None: ...

global___ExtendedLocation = ExtendedLocation

@typing_extensions.final
class HostGroupsHosts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTO_REPLACE_ON_FAILURE_FIELD_NUMBER: builtins.int
    LICENSE_TYPE_FIELD_NUMBER: builtins.int
    PLATFORM_FAULT_DOMAIN_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    auto_replace_on_failure: builtins.bool
    license_type: builtins.str
    platform_fault_domain: builtins.int
    @property
    def sku(self) -> global___Sku: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        auto_replace_on_failure: builtins.bool = ...,
        license_type: builtins.str = ...,
        platform_fault_domain: builtins.int = ...,
        sku: global___Sku | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_replace_on_failure", b"auto_replace_on_failure", "license_type", b"license_type", "location", b"location", "name", b"name", "platform_fault_domain", b"platform_fault_domain", "resource_info", b"resource_info", "sku", b"sku", "tags", b"tags"]) -> None: ...

global___HostGroupsHosts = HostGroupsHosts

@typing_extensions.final
class HostGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PLATFORM_FAULT_DOMAIN_COUNT_FIELD_NUMBER: builtins.int
    SUPPORT_AUTOMATIC_PLACEMENT_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    ZONES_FIELD_NUMBER: builtins.int
    HOST_GROUPS_HOSTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    platform_fault_domain_count: builtins.int
    support_automatic_placement: builtins.bool
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def zones(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def host_groups_hosts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostGroupsHosts]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        platform_fault_domain_count: builtins.int = ...,
        support_automatic_placement: builtins.bool = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        zones: collections.abc.Iterable[builtins.str] | None = ...,
        host_groups_hosts: collections.abc.Iterable[global___HostGroupsHosts] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_groups_hosts", b"host_groups_hosts", "location", b"location", "name", b"name", "platform_fault_domain_count", b"platform_fault_domain_count", "resource_info", b"resource_info", "support_automatic_placement", b"support_automatic_placement", "tags", b"tags", "zones", b"zones"]) -> None: ...

global___HostGroups = HostGroups

@typing_extensions.final
class CapacityReservationGroupsCapacityReservations(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    ZONES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    @property
    def sku(self) -> global___Sku: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def zones(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        sku: global___Sku | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        zones: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "name", b"name", "resource_info", b"resource_info", "sku", b"sku", "tags", b"tags", "zones", b"zones"]) -> None: ...

global___CapacityReservationGroupsCapacityReservations = CapacityReservationGroupsCapacityReservations

@typing_extensions.final
class CapacityReservationGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    ZONES_FIELD_NUMBER: builtins.int
    CAPACITY_RESERVATION_GROUPS_CAPACITY_RESERVATIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def zones(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def capacity_reservation_groups_capacity_reservations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CapacityReservationGroupsCapacityReservations]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        zones: collections.abc.Iterable[builtins.str] | None = ...,
        capacity_reservation_groups_capacity_reservations: collections.abc.Iterable[global___CapacityReservationGroupsCapacityReservations] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity_reservation_groups_capacity_reservations", b"capacity_reservation_groups_capacity_reservations", "location", b"location", "name", b"name", "resource_info", b"resource_info", "tags", b"tags", "zones", b"zones"]) -> None: ...

global___CapacityReservationGroups = CapacityReservationGroups

@typing_extensions.final
class AvailabilitySets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PLATFORM_FAULT_DOMAIN_COUNT_FIELD_NUMBER: builtins.int
    PLATFORM_UPDATE_DOMAIN_COUNT_FIELD_NUMBER: builtins.int
    PROXIMITY_PLACEMENT_GROUP_FIELD_NUMBER: builtins.int
    VIRTUAL_MACHINES_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    platform_fault_domain_count: builtins.int
    platform_update_domain_count: builtins.int
    proximity_placement_group: builtins.str
    @property
    def virtual_machines(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def sku(self) -> global___Sku: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        platform_fault_domain_count: builtins.int = ...,
        platform_update_domain_count: builtins.int = ...,
        proximity_placement_group: builtins.str = ...,
        virtual_machines: collections.abc.Iterable[builtins.str] | None = ...,
        sku: global___Sku | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "name", b"name", "platform_fault_domain_count", b"platform_fault_domain_count", "platform_update_domain_count", b"platform_update_domain_count", "proximity_placement_group", b"proximity_placement_group", "resource_info", b"resource_info", "sku", b"sku", "tags", b"tags", "virtual_machines", b"virtual_machines"]) -> None: ...

global___AvailabilitySets = AvailabilitySets

@typing_extensions.final
class Sku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPACITY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    capacity: builtins.int
    name: builtins.str
    tier: builtins.str
    def __init__(
        self,
        *,
        capacity: builtins.int = ...,
        name: builtins.str = ...,
        tier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity", b"capacity", "name", b"name", "tier", b"tier"]) -> None: ...

global___Sku = Sku



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_budgets.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61ws/aws_budgets.proto\x12\x17oak9.tython.aws.budgets\x1a\x13shared/shared.proto\"w\n\x10\x42udgetSubscriber\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11subscription_type\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\"\xb0\x01\n\x12\x42udgetNotification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x63omparison_operator\x18\x02 \x01(\t\x12\x19\n\x11notification_type\x18\x03 \x01(\t\x12\x11\n\tthreshold\x18\x04 \x01(\x01\x12\x16\n\x0ethreshold_type\x18\x05 \x01(\t\"\xdf\x01\n!BudgetNotificationWithSubscribers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12>\n\x0bsubscribers\x18\x02 \x03(\x0b\x32).oak9.tython.aws.budgets.BudgetSubscriber\x12\x41\n\x0cnotification\x18\x03 \x01(\x0b\x32+.oak9.tython.aws.budgets.BudgetNotification\"d\n\x0b\x42udgetSpend\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x12\x0c\n\x04unit\x18\x03 \x01(\t\"g\n\x10\x42udgetTimePeriod\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05start\x18\x02 \x01(\t\x12\x0b\n\x03\x65nd\x18\x03 \x01(\t\"\xe4\x02\n\x0f\x42udgetCostTypes\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0finclude_support\x18\x02 \x01(\x08\x12\"\n\x1ainclude_other_subscription\x18\x03 \x01(\x08\x12\x13\n\x0binclude_tax\x18\x04 \x01(\x08\x12\x1c\n\x14include_subscription\x18\x05 \x01(\x08\x12\x13\n\x0buse_blended\x18\x06 \x01(\x08\x12\x17\n\x0finclude_upfront\x18\x07 \x01(\x08\x12\x18\n\x10include_discount\x18\x08 \x01(\x08\x12\x16\n\x0einclude_credit\x18\t \x01(\x08\x12\x19\n\x11include_recurring\x18\n \x01(\x08\x12\x15\n\ruse_amortized\x18\x0b \x01(\x08\x12\x16\n\x0einclude_refund\x18\x0c \x01(\x08\"\xe7\x04\n\x10\x42udgetBudgetData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12:\n\x0c\x62udget_limit\x18\x02 \x01(\x0b\x32$.oak9.tython.aws.budgets.BudgetSpend\x12>\n\x0btime_period\x18\x03 \x01(\x0b\x32).oak9.tython.aws.budgets.BudgetTimePeriod\x12\x11\n\ttime_unit\x18\x04 \x01(\t\x12\x61\n\x15planned_budget_limits\x18\x05 \x03(\x0b\x32\x42.oak9.tython.aws.budgets.BudgetBudgetData.PlannedBudgetLimitsEntry\x12P\n\x0c\x63ost_filters\x18\x06 \x03(\x0b\x32:.oak9.tython.aws.budgets.BudgetBudgetData.CostFiltersEntry\x12\x13\n\x0b\x62udget_name\x18\x07 \x01(\t\x12<\n\ncost_types\x18\x08 \x01(\x0b\x32(.oak9.tython.aws.budgets.BudgetCostTypes\x12\x13\n\x0b\x62udget_type\x18\t \x01(\t\x1a:\n\x18PlannedBudgetLimitsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x43ostFiltersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe0\x01\n\x06\x42udget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x62\n\x1enotifications_with_subscribers\x18\x02 \x03(\x0b\x32:.oak9.tython.aws.budgets.BudgetNotificationWithSubscribers\x12\x39\n\x06\x62udget\x18\x03 \x01(\x0b\x32).oak9.tython.aws.budgets.BudgetBudgetData\":\n\x07\x42udgets\x12/\n\x06\x62udget\x18\x01 \x03(\x0b\x32\x1f.oak9.tython.aws.budgets.Budgetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_budgets_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BUDGETBUDGETDATA_PLANNEDBUDGETLIMITSENTRY._options = None
  _BUDGETBUDGETDATA_PLANNEDBUDGETLIMITSENTRY._serialized_options = b'8\001'
  _BUDGETBUDGETDATA_COSTFILTERSENTRY._options = None
  _BUDGETBUDGETDATA_COSTFILTERSENTRY._serialized_options = b'8\001'
  _BUDGETSUBSCRIBER._serialized_start=71
  _BUDGETSUBSCRIBER._serialized_end=190
  _BUDGETNOTIFICATION._serialized_start=193
  _BUDGETNOTIFICATION._serialized_end=369
  _BUDGETNOTIFICATIONWITHSUBSCRIBERS._serialized_start=372
  _BUDGETNOTIFICATIONWITHSUBSCRIBERS._serialized_end=595
  _BUDGETSPEND._serialized_start=597
  _BUDGETSPEND._serialized_end=697
  _BUDGETTIMEPERIOD._serialized_start=699
  _BUDGETTIMEPERIOD._serialized_end=802
  _BUDGETCOSTTYPES._serialized_start=805
  _BUDGETCOSTTYPES._serialized_end=1161
  _BUDGETBUDGETDATA._serialized_start=1164
  _BUDGETBUDGETDATA._serialized_end=1779
  _BUDGETBUDGETDATA_PLANNEDBUDGETLIMITSENTRY._serialized_start=1669
  _BUDGETBUDGETDATA_PLANNEDBUDGETLIMITSENTRY._serialized_end=1727
  _BUDGETBUDGETDATA_COSTFILTERSENTRY._serialized_start=1729
  _BUDGETBUDGETDATA_COSTFILTERSENTRY._serialized_end=1779
  _BUDGET._serialized_start=1782
  _BUDGET._serialized_end=2006
  _BUDGETS._serialized_start=2008
  _BUDGETS._serialized_end=2066
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CodeRepositoryGitConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SECRET_ARN_FIELD_NUMBER: builtins.int
    BRANCH_FIELD_NUMBER: builtins.int
    REPOSITORY_URL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    secret_arn: builtins.str
    branch: builtins.str
    repository_url: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        secret_arn: builtins.str = ...,
        branch: builtins.str = ...,
        repository_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch", b"branch", "repository_url", b"repository_url", "resource_info", b"resource_info", "secret_arn", b"secret_arn"]) -> None: ...

global___CodeRepositoryGitConfig = CodeRepositoryGitConfig

@typing_extensions.final
class CodeRepository(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CODE_REPOSITORY_NAME_FIELD_NUMBER: builtins.int
    GIT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    code_repository_name: builtins.str
    @property
    def git_config(self) -> global___CodeRepositoryGitConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        code_repository_name: builtins.str = ...,
        git_config: global___CodeRepositoryGitConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["git_config", b"git_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["code_repository_name", b"code_repository_name", "git_config", b"git_config", "resource_info", b"resource_info"]) -> None: ...

global___CodeRepository = CodeRepository

@typing_extensions.final
class SageMaker(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_REPOSITORY_FIELD_NUMBER: builtins.int
    ENDPOINT_FIELD_NUMBER: builtins.int
    ENDPOINT_CONFIG_FIELD_NUMBER: builtins.int
    MODEL_FIELD_NUMBER: builtins.int
    MONITORING_SCHEDULE_FIELD_NUMBER: builtins.int
    NOTEBOOK_INSTANCE_FIELD_NUMBER: builtins.int
    NOTEBOOK_INSTANCE_LIFECYCLE_CONFIG_FIELD_NUMBER: builtins.int
    WORKTEAM_FIELD_NUMBER: builtins.int
    @property
    def code_repository(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CodeRepository]: ...
    @property
    def endpoint(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Endpoint]: ...
    @property
    def endpoint_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EndpointConfig]: ...
    @property
    def model(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Model]: ...
    @property
    def monitoring_schedule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MonitoringSchedule]: ...
    @property
    def notebook_instance(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NotebookInstance]: ...
    @property
    def notebook_instance_lifecycle_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NotebookInstanceLifecycleConfig]: ...
    @property
    def workteam(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Workteam]: ...
    def __init__(
        self,
        *,
        code_repository: collections.abc.Iterable[global___CodeRepository] | None = ...,
        endpoint: collections.abc.Iterable[global___Endpoint] | None = ...,
        endpoint_config: collections.abc.Iterable[global___EndpointConfig] | None = ...,
        model: collections.abc.Iterable[global___Model] | None = ...,
        monitoring_schedule: collections.abc.Iterable[global___MonitoringSchedule] | None = ...,
        notebook_instance: collections.abc.Iterable[global___NotebookInstance] | None = ...,
        notebook_instance_lifecycle_config: collections.abc.Iterable[global___NotebookInstanceLifecycleConfig] | None = ...,
        workteam: collections.abc.Iterable[global___Workteam] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code_repository", b"code_repository", "endpoint", b"endpoint", "endpoint_config", b"endpoint_config", "model", b"model", "monitoring_schedule", b"monitoring_schedule", "notebook_instance", b"notebook_instance", "notebook_instance_lifecycle_config", b"notebook_instance_lifecycle_config", "workteam", b"workteam"]) -> None: ...

global___SageMaker = SageMaker

@typing_extensions.final
class EndpointVariantProperty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VARIANT_PROPERTY_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    variant_property_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        variant_property_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "variant_property_type", b"variant_property_type"]) -> None: ...

global___EndpointVariantProperty = EndpointVariantProperty

@typing_extensions.final
class Endpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RETAIN_ALL_VARIANT_PROPERTIES_FIELD_NUMBER: builtins.int
    ENDPOINT_NAME_FIELD_NUMBER: builtins.int
    EXCLUDE_RETAINED_VARIANT_PROPERTIES_FIELD_NUMBER: builtins.int
    ENDPOINT_CONFIG_NAME_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    retain_all_variant_properties: builtins.bool
    endpoint_name: builtins.str
    @property
    def exclude_retained_variant_properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EndpointVariantProperty]: ...
    endpoint_config_name: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        retain_all_variant_properties: builtins.bool = ...,
        endpoint_name: builtins.str = ...,
        exclude_retained_variant_properties: collections.abc.Iterable[global___EndpointVariantProperty] | None = ...,
        endpoint_config_name: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoint_config_name", b"endpoint_config_name", "endpoint_name", b"endpoint_name", "exclude_retained_variant_properties", b"exclude_retained_variant_properties", "resource_info", b"resource_info", "retain_all_variant_properties", b"retain_all_variant_properties", "tags", b"tags"]) -> None: ...

global___Endpoint = Endpoint

@typing_extensions.final
class EndpointConfigCaptureOption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CAPTURE_MODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    capture_mode: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        capture_mode: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["capture_mode", b"capture_mode", "resource_info", b"resource_info"]) -> None: ...

global___EndpointConfigCaptureOption = EndpointConfigCaptureOption

@typing_extensions.final
class EndpointConfigCaptureContentTypeHeader(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    JSON_CONTENT_TYPES_FIELD_NUMBER: builtins.int
    CSV_CONTENT_TYPES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def json_content_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def csv_content_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        json_content_types: collections.abc.Iterable[builtins.str] | None = ...,
        csv_content_types: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["csv_content_types", b"csv_content_types", "json_content_types", b"json_content_types", "resource_info", b"resource_info"]) -> None: ...

global___EndpointConfigCaptureContentTypeHeader = EndpointConfigCaptureContentTypeHeader

@typing_extensions.final
class EndpointConfigDataCaptureConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CAPTURE_OPTIONS_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    DESTINATION_S3_URI_FIELD_NUMBER: builtins.int
    INITIAL_SAMPLING_PERCENTAGE_FIELD_NUMBER: builtins.int
    CAPTURE_CONTENT_TYPE_HEADER_FIELD_NUMBER: builtins.int
    ENABLE_CAPTURE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def capture_options(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EndpointConfigCaptureOption]: ...
    kms_key_id: builtins.str
    destination_s3_uri: builtins.str
    initial_sampling_percentage: builtins.int
    @property
    def capture_content_type_header(self) -> global___EndpointConfigCaptureContentTypeHeader: ...
    enable_capture: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        capture_options: collections.abc.Iterable[global___EndpointConfigCaptureOption] | None = ...,
        kms_key_id: builtins.str = ...,
        destination_s3_uri: builtins.str = ...,
        initial_sampling_percentage: builtins.int = ...,
        capture_content_type_header: global___EndpointConfigCaptureContentTypeHeader | None = ...,
        enable_capture: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["capture_content_type_header", b"capture_content_type_header", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["capture_content_type_header", b"capture_content_type_header", "capture_options", b"capture_options", "destination_s3_uri", b"destination_s3_uri", "enable_capture", b"enable_capture", "initial_sampling_percentage", b"initial_sampling_percentage", "kms_key_id", b"kms_key_id", "resource_info", b"resource_info"]) -> None: ...

global___EndpointConfigDataCaptureConfig = EndpointConfigDataCaptureConfig

@typing_extensions.final
class EndpointConfigProductionVariant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MODEL_NAME_FIELD_NUMBER: builtins.int
    VARIANT_NAME_FIELD_NUMBER: builtins.int
    INITIAL_INSTANCE_COUNT_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    ACCELERATOR_TYPE_FIELD_NUMBER: builtins.int
    INITIAL_VARIANT_WEIGHT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    model_name: builtins.str
    variant_name: builtins.str
    initial_instance_count: builtins.int
    instance_type: builtins.str
    accelerator_type: builtins.str
    initial_variant_weight: builtins.float
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        model_name: builtins.str = ...,
        variant_name: builtins.str = ...,
        initial_instance_count: builtins.int = ...,
        instance_type: builtins.str = ...,
        accelerator_type: builtins.str = ...,
        initial_variant_weight: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerator_type", b"accelerator_type", "initial_instance_count", b"initial_instance_count", "initial_variant_weight", b"initial_variant_weight", "instance_type", b"instance_type", "model_name", b"model_name", "resource_info", b"resource_info", "variant_name", b"variant_name"]) -> None: ...

global___EndpointConfigProductionVariant = EndpointConfigProductionVariant

@typing_extensions.final
class EndpointConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DATA_CAPTURE_CONFIG_FIELD_NUMBER: builtins.int
    PRODUCTION_VARIANTS_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    ENDPOINT_CONFIG_NAME_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def data_capture_config(self) -> global___EndpointConfigDataCaptureConfig: ...
    @property
    def production_variants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EndpointConfigProductionVariant]: ...
    kms_key_id: builtins.str
    endpoint_config_name: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        data_capture_config: global___EndpointConfigDataCaptureConfig | None = ...,
        production_variants: collections.abc.Iterable[global___EndpointConfigProductionVariant] | None = ...,
        kms_key_id: builtins.str = ...,
        endpoint_config_name: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_capture_config", b"data_capture_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_capture_config", b"data_capture_config", "endpoint_config_name", b"endpoint_config_name", "kms_key_id", b"kms_key_id", "production_variants", b"production_variants", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___EndpointConfig = EndpointConfig

@typing_extensions.final
class ModelContainerDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class EnvironmentEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTAINER_HOSTNAME_FIELD_NUMBER: builtins.int
    MODEL_PACKAGE_NAME_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    MODEL_DATA_URL_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    container_hostname: builtins.str
    model_package_name: builtins.str
    mode: builtins.str
    @property
    def environment(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    model_data_url: builtins.str
    image: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        container_hostname: builtins.str = ...,
        model_package_name: builtins.str = ...,
        mode: builtins.str = ...,
        environment: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        model_data_url: builtins.str = ...,
        image: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_hostname", b"container_hostname", "environment", b"environment", "image", b"image", "mode", b"mode", "model_data_url", b"model_data_url", "model_package_name", b"model_package_name", "resource_info", b"resource_info"]) -> None: ...

global___ModelContainerDefinition = ModelContainerDefinition

@typing_extensions.final
class ModelVpcConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SUBNETS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def subnets(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        subnets: collections.abc.Iterable[builtins.str] | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "security_group_ids", b"security_group_ids", "subnets", b"subnets"]) -> None: ...

global___ModelVpcConfig = ModelVpcConfig

@typing_extensions.final
class Model(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EXECUTION_ROLE_ARN_FIELD_NUMBER: builtins.int
    ENABLE_NETWORK_ISOLATION_FIELD_NUMBER: builtins.int
    PRIMARY_CONTAINER_FIELD_NUMBER: builtins.int
    MODEL_NAME_FIELD_NUMBER: builtins.int
    VPC_CONFIG_FIELD_NUMBER: builtins.int
    CONTAINERS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    execution_role_arn: builtins.str
    enable_network_isolation: builtins.bool
    @property
    def primary_container(self) -> global___ModelContainerDefinition: ...
    model_name: builtins.str
    @property
    def vpc_config(self) -> global___ModelVpcConfig: ...
    @property
    def containers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModelContainerDefinition]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        execution_role_arn: builtins.str = ...,
        enable_network_isolation: builtins.bool = ...,
        primary_container: global___ModelContainerDefinition | None = ...,
        model_name: builtins.str = ...,
        vpc_config: global___ModelVpcConfig | None = ...,
        containers: collections.abc.Iterable[global___ModelContainerDefinition] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["primary_container", b"primary_container", "resource_info", b"resource_info", "vpc_config", b"vpc_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["containers", b"containers", "enable_network_isolation", b"enable_network_isolation", "execution_role_arn", b"execution_role_arn", "model_name", b"model_name", "primary_container", b"primary_container", "resource_info", b"resource_info", "tags", b"tags", "vpc_config", b"vpc_config"]) -> None: ...

global___Model = Model

@typing_extensions.final
class MonitoringScheduleConstraintsResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_URI_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    s3_uri: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3_uri", b"s3_uri"]) -> None: ...

global___MonitoringScheduleConstraintsResource = MonitoringScheduleConstraintsResource

@typing_extensions.final
class MonitoringScheduleStatisticsResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_URI_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    s3_uri: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3_uri", b"s3_uri"]) -> None: ...

global___MonitoringScheduleStatisticsResource = MonitoringScheduleStatisticsResource

@typing_extensions.final
class MonitoringScheduleBaselineConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONSTRAINTS_RESOURCE_FIELD_NUMBER: builtins.int
    STATISTICS_RESOURCE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def constraints_resource(self) -> global___MonitoringScheduleConstraintsResource: ...
    @property
    def statistics_resource(self) -> global___MonitoringScheduleStatisticsResource: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        constraints_resource: global___MonitoringScheduleConstraintsResource | None = ...,
        statistics_resource: global___MonitoringScheduleStatisticsResource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["constraints_resource", b"constraints_resource", "resource_info", b"resource_info", "statistics_resource", b"statistics_resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["constraints_resource", b"constraints_resource", "resource_info", b"resource_info", "statistics_resource", b"statistics_resource"]) -> None: ...

global___MonitoringScheduleBaselineConfig = MonitoringScheduleBaselineConfig

@typing_extensions.final
class MonitoringScheduleEnvironment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___MonitoringScheduleEnvironment = MonitoringScheduleEnvironment

@typing_extensions.final
class MonitoringScheduleMonitoringAppSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTAINER_ARGUMENTS_FIELD_NUMBER: builtins.int
    CONTAINER_ENTRYPOINT_FIELD_NUMBER: builtins.int
    IMAGE_URI_FIELD_NUMBER: builtins.int
    POST_ANALYTICS_PROCESSOR_SOURCE_URI_FIELD_NUMBER: builtins.int
    RECORD_PREPROCESSOR_SOURCE_URI_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def container_arguments(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def container_entrypoint(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    image_uri: builtins.str
    post_analytics_processor_source_uri: builtins.str
    record_preprocessor_source_uri: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        container_arguments: collections.abc.Iterable[builtins.str] | None = ...,
        container_entrypoint: collections.abc.Iterable[builtins.str] | None = ...,
        image_uri: builtins.str = ...,
        post_analytics_processor_source_uri: builtins.str = ...,
        record_preprocessor_source_uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_arguments", b"container_arguments", "container_entrypoint", b"container_entrypoint", "image_uri", b"image_uri", "post_analytics_processor_source_uri", b"post_analytics_processor_source_uri", "record_preprocessor_source_uri", b"record_preprocessor_source_uri", "resource_info", b"resource_info"]) -> None: ...

global___MonitoringScheduleMonitoringAppSpecification = MonitoringScheduleMonitoringAppSpecification

@typing_extensions.final
class MonitoringScheduleEndpointInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENDPOINT_NAME_FIELD_NUMBER: builtins.int
    LOCAL_PATH_FIELD_NUMBER: builtins.int
    S3_DATA_DISTRIBUTION_TYPE_FIELD_NUMBER: builtins.int
    S3_INPUT_MODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    endpoint_name: builtins.str
    local_path: builtins.str
    s3_data_distribution_type: builtins.str
    s3_input_mode: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        endpoint_name: builtins.str = ...,
        local_path: builtins.str = ...,
        s3_data_distribution_type: builtins.str = ...,
        s3_input_mode: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoint_name", b"endpoint_name", "local_path", b"local_path", "resource_info", b"resource_info", "s3_data_distribution_type", b"s3_data_distribution_type", "s3_input_mode", b"s3_input_mode"]) -> None: ...

global___MonitoringScheduleEndpointInput = MonitoringScheduleEndpointInput

@typing_extensions.final
class MonitoringScheduleMonitoringInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENDPOINT_INPUT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def endpoint_input(self) -> global___MonitoringScheduleEndpointInput: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        endpoint_input: global___MonitoringScheduleEndpointInput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["endpoint_input", b"endpoint_input", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoint_input", b"endpoint_input", "resource_info", b"resource_info"]) -> None: ...

global___MonitoringScheduleMonitoringInput = MonitoringScheduleMonitoringInput

@typing_extensions.final
class MonitoringScheduleMonitoringInputs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MONITORING_INPUTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def monitoring_inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MonitoringScheduleMonitoringInput]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        monitoring_inputs: collections.abc.Iterable[global___MonitoringScheduleMonitoringInput] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["monitoring_inputs", b"monitoring_inputs", "resource_info", b"resource_info"]) -> None: ...

global___MonitoringScheduleMonitoringInputs = MonitoringScheduleMonitoringInputs

@typing_extensions.final
class MonitoringScheduleS3Output(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCAL_PATH_FIELD_NUMBER: builtins.int
    S3_UPLOAD_MODE_FIELD_NUMBER: builtins.int
    S3_URI_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    local_path: builtins.str
    s3_upload_mode: builtins.str
    s3_uri: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        local_path: builtins.str = ...,
        s3_upload_mode: builtins.str = ...,
        s3_uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["local_path", b"local_path", "resource_info", b"resource_info", "s3_upload_mode", b"s3_upload_mode", "s3_uri", b"s3_uri"]) -> None: ...

global___MonitoringScheduleS3Output = MonitoringScheduleS3Output

@typing_extensions.final
class MonitoringScheduleMonitoringOutput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_OUTPUT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def s3_output(self) -> global___MonitoringScheduleS3Output: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_output: global___MonitoringScheduleS3Output | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3_output", b"s3_output"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3_output", b"s3_output"]) -> None: ...

global___MonitoringScheduleMonitoringOutput = MonitoringScheduleMonitoringOutput

@typing_extensions.final
class MonitoringScheduleMonitoringOutputConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    MONITORING_OUTPUTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kms_key_id: builtins.str
    @property
    def monitoring_outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MonitoringScheduleMonitoringOutput]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kms_key_id: builtins.str = ...,
        monitoring_outputs: collections.abc.Iterable[global___MonitoringScheduleMonitoringOutput] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_id", b"kms_key_id", "monitoring_outputs", b"monitoring_outputs", "resource_info", b"resource_info"]) -> None: ...

global___MonitoringScheduleMonitoringOutputConfig = MonitoringScheduleMonitoringOutputConfig

@typing_extensions.final
class MonitoringScheduleClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INSTANCE_COUNT_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    VOLUME_KMS_KEY_ID_FIELD_NUMBER: builtins.int
    VOLUME_SIZE_IN_GB_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    instance_count: builtins.int
    instance_type: builtins.str
    volume_kms_key_id: builtins.str
    volume_size_in_gb: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        instance_count: builtins.int = ...,
        instance_type: builtins.str = ...,
        volume_kms_key_id: builtins.str = ...,
        volume_size_in_gb: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_count", b"instance_count", "instance_type", b"instance_type", "resource_info", b"resource_info", "volume_kms_key_id", b"volume_kms_key_id", "volume_size_in_gb", b"volume_size_in_gb"]) -> None: ...

global___MonitoringScheduleClusterConfig = MonitoringScheduleClusterConfig

@typing_extensions.final
class MonitoringScheduleMonitoringResources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLUSTER_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def cluster_config(self) -> global___MonitoringScheduleClusterConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cluster_config: global___MonitoringScheduleClusterConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster_config", b"cluster_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_config", b"cluster_config", "resource_info", b"resource_info"]) -> None: ...

global___MonitoringScheduleMonitoringResources = MonitoringScheduleMonitoringResources

@typing_extensions.final
class MonitoringScheduleVpcConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    SUBNETS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def subnets(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        subnets: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "security_group_ids", b"security_group_ids", "subnets", b"subnets"]) -> None: ...

global___MonitoringScheduleVpcConfig = MonitoringScheduleVpcConfig

@typing_extensions.final
class MonitoringScheduleNetworkConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLE_INTER_CONTAINER_TRAFFIC_ENCRYPTION_FIELD_NUMBER: builtins.int
    ENABLE_NETWORK_ISOLATION_FIELD_NUMBER: builtins.int
    VPC_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enable_inter_container_traffic_encryption: builtins.bool
    enable_network_isolation: builtins.bool
    @property
    def vpc_config(self) -> global___MonitoringScheduleVpcConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enable_inter_container_traffic_encryption: builtins.bool = ...,
        enable_network_isolation: builtins.bool = ...,
        vpc_config: global___MonitoringScheduleVpcConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "vpc_config", b"vpc_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_inter_container_traffic_encryption", b"enable_inter_container_traffic_encryption", "enable_network_isolation", b"enable_network_isolation", "resource_info", b"resource_info", "vpc_config", b"vpc_config"]) -> None: ...

global___MonitoringScheduleNetworkConfig = MonitoringScheduleNetworkConfig

@typing_extensions.final
class MonitoringScheduleStoppingCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAX_RUNTIME_IN_SECONDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    max_runtime_in_seconds: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        max_runtime_in_seconds: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_runtime_in_seconds", b"max_runtime_in_seconds", "resource_info", b"resource_info"]) -> None: ...

global___MonitoringScheduleStoppingCondition = MonitoringScheduleStoppingCondition

@typing_extensions.final
class MonitoringScheduleMonitoringJobDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BASELINE_CONFIG_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    MONITORING_APP_SPECIFICATION_FIELD_NUMBER: builtins.int
    MONITORING_INPUTS_FIELD_NUMBER: builtins.int
    MONITORING_OUTPUT_CONFIG_FIELD_NUMBER: builtins.int
    MONITORING_RESOURCES_FIELD_NUMBER: builtins.int
    NETWORK_CONFIG_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    STOPPING_CONDITION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def baseline_config(self) -> global___MonitoringScheduleBaselineConfig: ...
    @property
    def environment(self) -> global___MonitoringScheduleEnvironment: ...
    @property
    def monitoring_app_specification(self) -> global___MonitoringScheduleMonitoringAppSpecification: ...
    @property
    def monitoring_inputs(self) -> global___MonitoringScheduleMonitoringInputs: ...
    @property
    def monitoring_output_config(self) -> global___MonitoringScheduleMonitoringOutputConfig: ...
    @property
    def monitoring_resources(self) -> global___MonitoringScheduleMonitoringResources: ...
    @property
    def network_config(self) -> global___MonitoringScheduleNetworkConfig: ...
    role_arn: builtins.str
    @property
    def stopping_condition(self) -> global___MonitoringScheduleStoppingCondition: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        baseline_config: global___MonitoringScheduleBaselineConfig | None = ...,
        environment: global___MonitoringScheduleEnvironment | None = ...,
        monitoring_app_specification: global___MonitoringScheduleMonitoringAppSpecification | None = ...,
        monitoring_inputs: global___MonitoringScheduleMonitoringInputs | None = ...,
        monitoring_output_config: global___MonitoringScheduleMonitoringOutputConfig | None = ...,
        monitoring_resources: global___MonitoringScheduleMonitoringResources | None = ...,
        network_config: global___MonitoringScheduleNetworkConfig | None = ...,
        role_arn: builtins.str = ...,
        stopping_condition: global___MonitoringScheduleStoppingCondition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["baseline_config", b"baseline_config", "environment", b"environment", "monitoring_app_specification", b"monitoring_app_specification", "monitoring_inputs", b"monitoring_inputs", "monitoring_output_config", b"monitoring_output_config", "monitoring_resources", b"monitoring_resources", "network_config", b"network_config", "resource_info", b"resource_info", "stopping_condition", b"stopping_condition"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["baseline_config", b"baseline_config", "environment", b"environment", "monitoring_app_specification", b"monitoring_app_specification", "monitoring_inputs", b"monitoring_inputs", "monitoring_output_config", b"monitoring_output_config", "monitoring_resources", b"monitoring_resources", "network_config", b"network_config", "resource_info", b"resource_info", "role_arn", b"role_arn", "stopping_condition", b"stopping_condition"]) -> None: ...

global___MonitoringScheduleMonitoringJobDefinition = MonitoringScheduleMonitoringJobDefinition

@typing_extensions.final
class MonitoringScheduleScheduleConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SCHEDULE_EXPRESSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    schedule_expression: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        schedule_expression: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "schedule_expression", b"schedule_expression"]) -> None: ...

global___MonitoringScheduleScheduleConfig = MonitoringScheduleScheduleConfig

@typing_extensions.final
class MonitoringScheduleMonitoringScheduleConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MONITORING_JOB_DEFINITION_FIELD_NUMBER: builtins.int
    SCHEDULE_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def monitoring_job_definition(self) -> global___MonitoringScheduleMonitoringJobDefinition: ...
    @property
    def schedule_config(self) -> global___MonitoringScheduleScheduleConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        monitoring_job_definition: global___MonitoringScheduleMonitoringJobDefinition | None = ...,
        schedule_config: global___MonitoringScheduleScheduleConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["monitoring_job_definition", b"monitoring_job_definition", "resource_info", b"resource_info", "schedule_config", b"schedule_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["monitoring_job_definition", b"monitoring_job_definition", "resource_info", b"resource_info", "schedule_config", b"schedule_config"]) -> None: ...

global___MonitoringScheduleMonitoringScheduleConfig = MonitoringScheduleMonitoringScheduleConfig

@typing_extensions.final
class MonitoringScheduleMonitoringExecutionSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CREATION_TIME_FIELD_NUMBER: builtins.int
    ENDPOINT_NAME_FIELD_NUMBER: builtins.int
    FAILURE_REASON_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_TIME_FIELD_NUMBER: builtins.int
    MONITORING_EXECUTION_STATUS_FIELD_NUMBER: builtins.int
    MONITORING_SCHEDULE_NAME_FIELD_NUMBER: builtins.int
    PROCESSING_JOB_ARN_FIELD_NUMBER: builtins.int
    SCHEDULED_TIME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    creation_time: builtins.str
    endpoint_name: builtins.str
    failure_reason: builtins.str
    last_modified_time: builtins.str
    monitoring_execution_status: builtins.str
    monitoring_schedule_name: builtins.str
    processing_job_arn: builtins.str
    scheduled_time: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        creation_time: builtins.str = ...,
        endpoint_name: builtins.str = ...,
        failure_reason: builtins.str = ...,
        last_modified_time: builtins.str = ...,
        monitoring_execution_status: builtins.str = ...,
        monitoring_schedule_name: builtins.str = ...,
        processing_job_arn: builtins.str = ...,
        scheduled_time: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_time", b"creation_time", "endpoint_name", b"endpoint_name", "failure_reason", b"failure_reason", "last_modified_time", b"last_modified_time", "monitoring_execution_status", b"monitoring_execution_status", "monitoring_schedule_name", b"monitoring_schedule_name", "processing_job_arn", b"processing_job_arn", "resource_info", b"resource_info", "scheduled_time", b"scheduled_time"]) -> None: ...

global___MonitoringScheduleMonitoringExecutionSummary = MonitoringScheduleMonitoringExecutionSummary

@typing_extensions.final
class MonitoringSchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MONITORING_SCHEDULE_ARN_FIELD_NUMBER: builtins.int
    MONITORING_SCHEDULE_NAME_FIELD_NUMBER: builtins.int
    MONITORING_SCHEDULE_CONFIG_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    CREATION_TIME_FIELD_NUMBER: builtins.int
    ENDPOINT_NAME_FIELD_NUMBER: builtins.int
    FAILURE_REASON_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_TIME_FIELD_NUMBER: builtins.int
    LAST_MONITORING_EXECUTION_SUMMARY_FIELD_NUMBER: builtins.int
    MONITORING_SCHEDULE_STATUS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    monitoring_schedule_arn: builtins.str
    monitoring_schedule_name: builtins.str
    @property
    def monitoring_schedule_config(self) -> global___MonitoringScheduleMonitoringScheduleConfig: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    creation_time: builtins.str
    endpoint_name: builtins.str
    failure_reason: builtins.str
    last_modified_time: builtins.str
    @property
    def last_monitoring_execution_summary(self) -> global___MonitoringScheduleMonitoringExecutionSummary: ...
    monitoring_schedule_status: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        monitoring_schedule_arn: builtins.str = ...,
        monitoring_schedule_name: builtins.str = ...,
        monitoring_schedule_config: global___MonitoringScheduleMonitoringScheduleConfig | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        creation_time: builtins.str = ...,
        endpoint_name: builtins.str = ...,
        failure_reason: builtins.str = ...,
        last_modified_time: builtins.str = ...,
        last_monitoring_execution_summary: global___MonitoringScheduleMonitoringExecutionSummary | None = ...,
        monitoring_schedule_status: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_monitoring_execution_summary", b"last_monitoring_execution_summary", "monitoring_schedule_config", b"monitoring_schedule_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_time", b"creation_time", "endpoint_name", b"endpoint_name", "failure_reason", b"failure_reason", "last_modified_time", b"last_modified_time", "last_monitoring_execution_summary", b"last_monitoring_execution_summary", "monitoring_schedule_arn", b"monitoring_schedule_arn", "monitoring_schedule_config", b"monitoring_schedule_config", "monitoring_schedule_name", b"monitoring_schedule_name", "monitoring_schedule_status", b"monitoring_schedule_status", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___MonitoringSchedule = MonitoringSchedule

@typing_extensions.final
class NotebookInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    VOLUME_SIZE_IN_GB_FIELD_NUMBER: builtins.int
    ADDITIONAL_CODE_REPOSITORIES_FIELD_NUMBER: builtins.int
    DEFAULT_CODE_REPOSITORY_FIELD_NUMBER: builtins.int
    DIRECT_INTERNET_ACCESS_FIELD_NUMBER: builtins.int
    ACCELERATOR_TYPES_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    ROOT_ACCESS_FIELD_NUMBER: builtins.int
    NOTEBOOK_INSTANCE_NAME_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    LIFECYCLE_CONFIG_NAME_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kms_key_id: builtins.str
    volume_size_in_gb: builtins.int
    @property
    def additional_code_repositories(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    default_code_repository: builtins.str
    direct_internet_access: builtins.str
    @property
    def accelerator_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    subnet_id: builtins.str
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role_arn: builtins.str
    root_access: builtins.str
    notebook_instance_name: builtins.str
    instance_type: builtins.str
    lifecycle_config_name: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kms_key_id: builtins.str = ...,
        volume_size_in_gb: builtins.int = ...,
        additional_code_repositories: collections.abc.Iterable[builtins.str] | None = ...,
        default_code_repository: builtins.str = ...,
        direct_internet_access: builtins.str = ...,
        accelerator_types: collections.abc.Iterable[builtins.str] | None = ...,
        subnet_id: builtins.str = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        role_arn: builtins.str = ...,
        root_access: builtins.str = ...,
        notebook_instance_name: builtins.str = ...,
        instance_type: builtins.str = ...,
        lifecycle_config_name: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerator_types", b"accelerator_types", "additional_code_repositories", b"additional_code_repositories", "default_code_repository", b"default_code_repository", "direct_internet_access", b"direct_internet_access", "instance_type", b"instance_type", "kms_key_id", b"kms_key_id", "lifecycle_config_name", b"lifecycle_config_name", "notebook_instance_name", b"notebook_instance_name", "resource_info", b"resource_info", "role_arn", b"role_arn", "root_access", b"root_access", "security_group_ids", b"security_group_ids", "subnet_id", b"subnet_id", "tags", b"tags", "volume_size_in_gb", b"volume_size_in_gb"]) -> None: ...

global___NotebookInstance = NotebookInstance

@typing_extensions.final
class NotebookInstanceLifecycleConfigNotebookInstanceLifecycleHook(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    content: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        content: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "resource_info", b"resource_info"]) -> None: ...

global___NotebookInstanceLifecycleConfigNotebookInstanceLifecycleHook = NotebookInstanceLifecycleConfigNotebookInstanceLifecycleHook

@typing_extensions.final
class NotebookInstanceLifecycleConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ON_START_FIELD_NUMBER: builtins.int
    NOTEBOOK_INSTANCE_LIFECYCLE_CONFIG_NAME_FIELD_NUMBER: builtins.int
    ON_CREATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def on_start(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NotebookInstanceLifecycleConfigNotebookInstanceLifecycleHook]: ...
    notebook_instance_lifecycle_config_name: builtins.str
    @property
    def on_create(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NotebookInstanceLifecycleConfigNotebookInstanceLifecycleHook]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        on_start: collections.abc.Iterable[global___NotebookInstanceLifecycleConfigNotebookInstanceLifecycleHook] | None = ...,
        notebook_instance_lifecycle_config_name: builtins.str = ...,
        on_create: collections.abc.Iterable[global___NotebookInstanceLifecycleConfigNotebookInstanceLifecycleHook] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["notebook_instance_lifecycle_config_name", b"notebook_instance_lifecycle_config_name", "on_create", b"on_create", "on_start", b"on_start", "resource_info", b"resource_info"]) -> None: ...

global___NotebookInstanceLifecycleConfig = NotebookInstanceLifecycleConfig

@typing_extensions.final
class WorkteamNotificationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NOTIFICATION_TOPIC_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    notification_topic_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        notification_topic_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["notification_topic_arn", b"notification_topic_arn", "resource_info", b"resource_info"]) -> None: ...

global___WorkteamNotificationConfiguration = WorkteamNotificationConfiguration

@typing_extensions.final
class WorkteamCognitoMemberDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COGNITO_USER_POOL_FIELD_NUMBER: builtins.int
    COGNITO_CLIENT_ID_FIELD_NUMBER: builtins.int
    COGNITO_USER_GROUP_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cognito_user_pool: builtins.str
    cognito_client_id: builtins.str
    cognito_user_group: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cognito_user_pool: builtins.str = ...,
        cognito_client_id: builtins.str = ...,
        cognito_user_group: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cognito_client_id", b"cognito_client_id", "cognito_user_group", b"cognito_user_group", "cognito_user_pool", b"cognito_user_pool", "resource_info", b"resource_info"]) -> None: ...

global___WorkteamCognitoMemberDefinition = WorkteamCognitoMemberDefinition

@typing_extensions.final
class WorkteamMemberDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COGNITO_MEMBER_DEFINITION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def cognito_member_definition(self) -> global___WorkteamCognitoMemberDefinition: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cognito_member_definition: global___WorkteamCognitoMemberDefinition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cognito_member_definition", b"cognito_member_definition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cognito_member_definition", b"cognito_member_definition", "resource_info", b"resource_info"]) -> None: ...

global___WorkteamMemberDefinition = WorkteamMemberDefinition

@typing_extensions.final
class Workteam(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    NOTIFICATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    WORKTEAM_NAME_FIELD_NUMBER: builtins.int
    MEMBER_DEFINITIONS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def notification_configuration(self) -> global___WorkteamNotificationConfiguration: ...
    workteam_name: builtins.str
    @property
    def member_definitions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WorkteamMemberDefinition]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        notification_configuration: global___WorkteamNotificationConfiguration | None = ...,
        workteam_name: builtins.str = ...,
        member_definitions: collections.abc.Iterable[global___WorkteamMemberDefinition] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["notification_configuration", b"notification_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "member_definitions", b"member_definitions", "notification_configuration", b"notification_configuration", "resource_info", b"resource_info", "tags", b"tags", "workteam_name", b"workteam_name"]) -> None: ...

global___Workteam = Workteam



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.api.core.v1_pb2
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Endpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DeprecatedTopologyEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ADDRESSES_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    DEPRECATED_TOPOLOGY_FIELD_NUMBER: builtins.int
    HINTS_FIELD_NUMBER: builtins.int
    HOSTNAME_FIELD_NUMBER: builtins.int
    NODE_NAME_FIELD_NUMBER: builtins.int
    TARGET_REF_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def conditions(self) -> global___EndpointConditions: ...
    @property
    def deprecated_topology(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def hints(self) -> global___EndpointHints: ...
    hostname: builtins.str
    node_name: builtins.str
    @property
    def target_ref(self) -> kubernetes.kubernetes_io.k8s.api.core.v1_pb2.ObjectReference: ...
    zone: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        addresses: collections.abc.Iterable[builtins.str] | None = ...,
        conditions: global___EndpointConditions | None = ...,
        deprecated_topology: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        hints: global___EndpointHints | None = ...,
        hostname: builtins.str = ...,
        node_name: builtins.str = ...,
        target_ref: kubernetes.kubernetes_io.k8s.api.core.v1_pb2.ObjectReference | None = ...,
        zone: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["conditions", b"conditions", "hints", b"hints", "resource_info", b"resource_info", "target_ref", b"target_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["addresses", b"addresses", "conditions", b"conditions", "deprecated_topology", b"deprecated_topology", "hints", b"hints", "hostname", b"hostname", "node_name", b"node_name", "resource_info", b"resource_info", "target_ref", b"target_ref", "zone", b"zone"]) -> None: ...

global___Endpoint = Endpoint

@typing_extensions.final
class EndpointConditions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    READY_FIELD_NUMBER: builtins.int
    SERVING_FIELD_NUMBER: builtins.int
    TERMINATING_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ready: builtins.bool
    serving: builtins.bool
    terminating: builtins.bool
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        ready: builtins.bool = ...,
        serving: builtins.bool = ...,
        terminating: builtins.bool = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ready", b"ready", "resource_info", b"resource_info", "serving", b"serving", "terminating", b"terminating"]) -> None: ...

global___EndpointConditions = EndpointConditions

@typing_extensions.final
class EndpointHints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOR_ZONES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def for_zones(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ForZone]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        for_zones: collections.abc.Iterable[global___ForZone] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["for_zones", b"for_zones", "resource_info", b"resource_info"]) -> None: ...

global___EndpointHints = EndpointHints

@typing_extensions.final
class EndpointPort(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_PROTOCOL_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    app_protocol: builtins.str
    name: builtins.str
    port: builtins.int
    protocol: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        app_protocol: builtins.str = ...,
        name: builtins.str = ...,
        port: builtins.int = ...,
        protocol: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_protocol", b"app_protocol", "name", b"name", "port", b"port", "protocol", b"protocol", "resource_info", b"resource_info"]) -> None: ...

global___EndpointPort = EndpointPort

@typing_extensions.final
class EndpointSlice(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_TYPE_FIELD_NUMBER: builtins.int
    API_VERSION_FIELD_NUMBER: builtins.int
    ENDPOINTS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    address_type: builtins.str
    api_version: builtins.str
    @property
    def endpoints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Endpoint]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EndpointPort]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        address_type: builtins.str = ...,
        api_version: builtins.str = ...,
        endpoints: collections.abc.Iterable[global___Endpoint] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        ports: collections.abc.Iterable[global___EndpointPort] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address_type", b"address_type", "api_version", b"api_version", "endpoints", b"endpoints", "kind", b"kind", "metadata", b"metadata", "ports", b"ports", "resource_info", b"resource_info"]) -> None: ...

global___EndpointSlice = EndpointSlice

@typing_extensions.final
class EndpointSliceList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EndpointSlice]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___EndpointSlice] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___EndpointSliceList = EndpointSliceList

@typing_extensions.final
class ForZone(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ForZone = ForZone



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class FileSystemLustreConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DRIVE_CACHE_TYPE_FIELD_NUMBER: builtins.int
    IMPORT_PATH_FIELD_NUMBER: builtins.int
    WEEKLY_MAINTENANCE_START_TIME_FIELD_NUMBER: builtins.int
    AUTO_IMPORT_POLICY_FIELD_NUMBER: builtins.int
    IMPORTED_FILE_CHUNK_SIZE_FIELD_NUMBER: builtins.int
    DEPLOYMENT_TYPE_FIELD_NUMBER: builtins.int
    DAILY_AUTOMATIC_BACKUP_START_TIME_FIELD_NUMBER: builtins.int
    COPY_TAGS_TO_BACKUPS_FIELD_NUMBER: builtins.int
    EXPORT_PATH_FIELD_NUMBER: builtins.int
    PER_UNIT_STORAGE_THROUGHPUT_FIELD_NUMBER: builtins.int
    AUTOMATIC_BACKUP_RETENTION_DAYS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    drive_cache_type: builtins.str
    import_path: builtins.str
    weekly_maintenance_start_time: builtins.str
    auto_import_policy: builtins.str
    imported_file_chunk_size: builtins.int
    deployment_type: builtins.str
    daily_automatic_backup_start_time: builtins.str
    copy_tags_to_backups: builtins.bool
    export_path: builtins.str
    per_unit_storage_throughput: builtins.int
    automatic_backup_retention_days: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        drive_cache_type: builtins.str = ...,
        import_path: builtins.str = ...,
        weekly_maintenance_start_time: builtins.str = ...,
        auto_import_policy: builtins.str = ...,
        imported_file_chunk_size: builtins.int = ...,
        deployment_type: builtins.str = ...,
        daily_automatic_backup_start_time: builtins.str = ...,
        copy_tags_to_backups: builtins.bool = ...,
        export_path: builtins.str = ...,
        per_unit_storage_throughput: builtins.int = ...,
        automatic_backup_retention_days: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_import_policy", b"auto_import_policy", "automatic_backup_retention_days", b"automatic_backup_retention_days", "copy_tags_to_backups", b"copy_tags_to_backups", "daily_automatic_backup_start_time", b"daily_automatic_backup_start_time", "deployment_type", b"deployment_type", "drive_cache_type", b"drive_cache_type", "export_path", b"export_path", "import_path", b"import_path", "imported_file_chunk_size", b"imported_file_chunk_size", "per_unit_storage_throughput", b"per_unit_storage_throughput", "resource_info", b"resource_info", "weekly_maintenance_start_time", b"weekly_maintenance_start_time"]) -> None: ...

global___FileSystemLustreConfiguration = FileSystemLustreConfiguration

@typing_extensions.final
class FileSystemSelfManagedActiveDirectoryConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FILE_SYSTEM_ADMINISTRATORS_GROUP_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    ORGANIZATIONAL_UNIT_DISTINGUISHED_NAME_FIELD_NUMBER: builtins.int
    DNS_IPS_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    file_system_administrators_group: builtins.str
    user_name: builtins.str
    domain_name: builtins.str
    organizational_unit_distinguished_name: builtins.str
    @property
    def dns_ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    password: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        file_system_administrators_group: builtins.str = ...,
        user_name: builtins.str = ...,
        domain_name: builtins.str = ...,
        organizational_unit_distinguished_name: builtins.str = ...,
        dns_ips: collections.abc.Iterable[builtins.str] | None = ...,
        password: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dns_ips", b"dns_ips", "domain_name", b"domain_name", "file_system_administrators_group", b"file_system_administrators_group", "organizational_unit_distinguished_name", b"organizational_unit_distinguished_name", "password", b"password", "resource_info", b"resource_info", "user_name", b"user_name"]) -> None: ...

global___FileSystemSelfManagedActiveDirectoryConfiguration = FileSystemSelfManagedActiveDirectoryConfiguration

@typing_extensions.final
class FileSystemWindowsConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SELF_MANAGED_ACTIVE_DIRECTORY_CONFIGURATION_FIELD_NUMBER: builtins.int
    WEEKLY_MAINTENANCE_START_TIME_FIELD_NUMBER: builtins.int
    ACTIVE_DIRECTORY_ID_FIELD_NUMBER: builtins.int
    DEPLOYMENT_TYPE_FIELD_NUMBER: builtins.int
    THROUGHPUT_CAPACITY_FIELD_NUMBER: builtins.int
    COPY_TAGS_TO_BACKUPS_FIELD_NUMBER: builtins.int
    DAILY_AUTOMATIC_BACKUP_START_TIME_FIELD_NUMBER: builtins.int
    AUTOMATIC_BACKUP_RETENTION_DAYS_FIELD_NUMBER: builtins.int
    PREFERRED_SUBNET_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def self_managed_active_directory_configuration(self) -> global___FileSystemSelfManagedActiveDirectoryConfiguration: ...
    weekly_maintenance_start_time: builtins.str
    active_directory_id: builtins.str
    deployment_type: builtins.str
    throughput_capacity: builtins.int
    copy_tags_to_backups: builtins.bool
    daily_automatic_backup_start_time: builtins.str
    automatic_backup_retention_days: builtins.int
    preferred_subnet_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        self_managed_active_directory_configuration: global___FileSystemSelfManagedActiveDirectoryConfiguration | None = ...,
        weekly_maintenance_start_time: builtins.str = ...,
        active_directory_id: builtins.str = ...,
        deployment_type: builtins.str = ...,
        throughput_capacity: builtins.int = ...,
        copy_tags_to_backups: builtins.bool = ...,
        daily_automatic_backup_start_time: builtins.str = ...,
        automatic_backup_retention_days: builtins.int = ...,
        preferred_subnet_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "self_managed_active_directory_configuration", b"self_managed_active_directory_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["active_directory_id", b"active_directory_id", "automatic_backup_retention_days", b"automatic_backup_retention_days", "copy_tags_to_backups", b"copy_tags_to_backups", "daily_automatic_backup_start_time", b"daily_automatic_backup_start_time", "deployment_type", b"deployment_type", "preferred_subnet_id", b"preferred_subnet_id", "resource_info", b"resource_info", "self_managed_active_directory_configuration", b"self_managed_active_directory_configuration", "throughput_capacity", b"throughput_capacity", "weekly_maintenance_start_time", b"weekly_maintenance_start_time"]) -> None: ...

global___FileSystemWindowsConfiguration = FileSystemWindowsConfiguration

@typing_extensions.final
class FileSystem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    STORAGE_TYPE_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    STORAGE_CAPACITY_FIELD_NUMBER: builtins.int
    FILE_SYSTEM_TYPE_FIELD_NUMBER: builtins.int
    LUSTRE_CONFIGURATION_FIELD_NUMBER: builtins.int
    BACKUP_ID_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    WINDOWS_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    storage_type: builtins.str
    kms_key_id: builtins.str
    storage_capacity: builtins.int
    file_system_type: builtins.str
    @property
    def lustre_configuration(self) -> global___FileSystemLustreConfiguration: ...
    backup_id: builtins.str
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def windows_configuration(self) -> global___FileSystemWindowsConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        storage_type: builtins.str = ...,
        kms_key_id: builtins.str = ...,
        storage_capacity: builtins.int = ...,
        file_system_type: builtins.str = ...,
        lustre_configuration: global___FileSystemLustreConfiguration | None = ...,
        backup_id: builtins.str = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        windows_configuration: global___FileSystemWindowsConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["lustre_configuration", b"lustre_configuration", "resource_info", b"resource_info", "windows_configuration", b"windows_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_id", b"backup_id", "file_system_type", b"file_system_type", "kms_key_id", b"kms_key_id", "lustre_configuration", b"lustre_configuration", "resource_info", b"resource_info", "security_group_ids", b"security_group_ids", "storage_capacity", b"storage_capacity", "storage_type", b"storage_type", "subnet_ids", b"subnet_ids", "tags", b"tags", "windows_configuration", b"windows_configuration"]) -> None: ...

global___FileSystem = FileSystem

@typing_extensions.final
class FSx(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_SYSTEM_FIELD_NUMBER: builtins.int
    @property
    def file_system(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FileSystem]: ...
    def __init__(
        self,
        *,
        file_system: collections.abc.Iterable[global___FileSystem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_system", b"file_system"]) -> None: ...

global___FSx = FSx
